###############################################################################
### Progress.pm (Yggdrasil::Progress)
### Base class for various progress indicators
###
### Copyright (C) 2003 Morten Wulff <wulff@psyke.org>
###
### This program is free software; you can redistribute it and/or
### modify it under the terms of the GNU General Public License
### as published by the Free Software Foundation; either version 2
### of the License, or (at your option) any later version.
###
### This program is distributed in the hope that it will be useful,
### but WITHOUT ANY WARRANTY; without even the implied warranty of
### MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
### GNU General Public License for more details.
###
### You should have received a copy of the GNU General Public License
### along with this program; if not, write to the Free Software
### Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
###############################################################################

### REVISIONS
### 1.0.0 : 2003-04-08 : Morten Wulff <wulff@psyke.org>
### 1.0.1 : 2003-04-10 : Morten Wulff <wulff@psyke.org>
###         Now uses Carp
### 1.1.0 : 2003-04-24 : Morten Wulff <wulff@psyke.org>
###         Progress indicators have been split in separate modules

package Yggdrasil::Progress;

use strict;
use warnings;

$|++;

use Carp;

###############################################################################
### INIT
###############################################################################

our $AUTOLOAD;

###############################################################################
### PUBLIC METHODS
###############################################################################

###############################################################################
sub new {
    my $proto = shift;
    my $class = ref($proto) || $proto;

    my $self = {
        counter => 0
    };

    bless($self, $class);
    return $self;
}

###############################################################################
### PRIVATE METHODS
###############################################################################

###############################################################################
sub AUTOLOAD {
    my $self = shift;
    my $type = ref($self) or croak "$self is not an object";

    my $name = $AUTOLOAD;
    $name =~ s/.*://;

    unless (exists $self->{_permitted}->{$name} ) {
        croak "Can't access `$name' field in class $type";
    }

    if (@_) {
        return $self->{$name} = shift;
    }
    else {
        return $self->{$name};
    }
}

1;

###############################################################################
### DOCUMENTATION
###############################################################################

__END__

=head1 NAME

Yggdrasil::Progress - Base class for various progress indicators

=head1 SYNOPSIS

=head1 DESCRIPTION

=head1 BUGS

no known bugs.

=head1 AUTHOR

Morten Wulff <wulff@psyke.org>

Copyright (C) 2003 Morten Wulff

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

=head1 VERSION

Version 1.0.1
